Struct gamemstr_common::AttributeInfo
source · pub struct AttributeInfo {
pub name: String,
pub description: String,
}Fields
name: Stringdescription: StringTrait Implementations
sourceimpl Clone for AttributeInfo
impl Clone for AttributeInfo
sourcefn clone(&self) -> AttributeInfo
fn clone(&self) -> AttributeInfo
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AttributeInfo
impl Debug for AttributeInfo
sourceimpl<'de> Deserialize<'de> for AttributeInfo
impl<'de> Deserialize<'de> for AttributeInfo
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Display for AttributeInfo
impl Display for AttributeInfo
sourceimpl Hash for AttributeInfo
impl Hash for AttributeInfo
sourceimpl Ord for AttributeInfo
impl Ord for AttributeInfo
sourcefn cmp(&self, other: &AttributeInfo) -> Ordering
fn cmp(&self, other: &AttributeInfo) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq<AttributeInfo> for AttributeInfo
impl PartialEq<AttributeInfo> for AttributeInfo
sourcefn eq(&self, other: &AttributeInfo) -> bool
fn eq(&self, other: &AttributeInfo) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<AttributeInfo> for AttributeInfo
impl PartialOrd<AttributeInfo> for AttributeInfo
sourcefn partial_cmp(&self, other: &AttributeInfo) -> Option<Ordering>
fn partial_cmp(&self, other: &AttributeInfo) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read more